@@ -3,8 +3,9 @@ from .terminal import Terminal
 from .box import Box
 from .waiting import Waiting
 from . import BoxStyles
+from .progressbar import ProgressBar
 
 from colorama import init as _colorama_init
 _colorama_init()
 
-__all__ = ['Terminal', 'Box', 'BoxStyles', 'Waiting']
\ No newline at end of file
+__all__ = ['Terminal', 'Box', 'BoxStyles', 'Waiting', 'ProgressBar']
\ No newline at end of file
